# GraphQL Compose: Configs

A Drupal module that extends GraphQL Compose to expose Drupal configuration through GraphQL.

## Overview

This module allows you to selectively expose Drupal configuration through GraphQL, providing type-safe access to configuration data. It integrates with the GraphQL Compose plugin system to provide a seamless experience for exposing and querying configuration data.

## Features

- Expose any Drupal configuration through GraphQL
- Selectively choose which configuration fields to expose
- Automatic type generation for exposed configurations
- Integration with GraphQL Compose's schema system
- Administrative interface for managing configuration exposure
- Type-safe access to configuration data

## Installation

1. Install the module using Composer:
   ```bash
   composer require drupal/graphql_compose_configs
   ```

2. Enable the module through the Drupal admin interface or using Drush:
   ```bash
   drush en graphql_compose_configs
   ```

## Usage

### Exposing Configuration

1. Navigate to `/admin/config/graphql/compose/configs`
2. Click "Add configuration exposure"
3. Select the configuration you want to expose
4. Choose which fields to expose
5. Save the configuration
6. Clear the cache to regenerate the GraphQL schema

### Querying Configuration

Once a configuration is exposed, you can query it using GraphQL. For example, to query the system.site configuration:

```graphql
query {
  systemSite {
    name
    mail
    slogan
  }
}
```

The module automatically converts configuration names to valid GraphQL type names (e.g., "system.site" becomes "systemSite").

## Permissions

The module defines the following permission:

- **Administer GraphQL configuration exposure**: Allows users to manage which configurations are exposed through GraphQL.
