<?php

namespace Drupal\graphql_compose_configs\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\Core\Entity\EntityStorageInterface;

/**
 * Defines the Configuration Exposure entity.
 *
 * @ConfigEntityType(
 *   id = "graphql_config_exposure",
 *   label = @Translation("GraphQL Configuration Exposure"),
 *   handlers = {
 *     "list_builder" = "Drupal\graphql_compose_configs\ConfigurationExposureListBuilder",
 *     "form" = {
 *       "add" = "Drupal\graphql_compose_configs\Form\ConfigurationExposureForm",
 *       "edit" = "Drupal\graphql_compose_configs\Form\ConfigurationExposureForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm"
 *     }
 *   },
 *   config_prefix = "exposure",
 *   admin_permission = "administer graphql configuration exposure",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "config_name",
 *     "exposed_fields"
 *   },
 *   links = {
 *     "collection" = "/admin/config/graphql/compose/configs",
 *     "add-form" = "/admin/config/graphql/compose/configs/add",
 *     "edit-form" = "/admin/config/graphql/compose/configs/{graphql_config_exposure}",
 *     "delete-form" = "/admin/config/graphql/compose/configs/{graphql_config_exposure}/delete"
 *   }
 * )
 */
class ConfigurationExposure extends ConfigEntityBase {

  /**
   * The Configuration Exposure ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The Configuration Exposure label.
   *
   * @var string
   */
  protected $label;

  /**
   * The configuration name to expose.
   *
   * @var string
   */
  protected $config_name;

  /**
   * The fields to expose from the configuration.
   *
   * @var array
   */
  protected $exposed_fields = [];

  /**
   * Gets the configuration name.
   *
   * @return string
   *   The configuration name.
   */
  public function getConfigName() {
    return $this->config_name;
  }

  /**
   * Gets the exposed fields.
   *
   * @return array
   *   The exposed fields.
   */
  public function getExposedFields() {
    return $this->exposed_fields;
  }

  /**
   * {@inheritdoc}
   */
  public function preSave(EntityStorageInterface $storage) {
    parent::preSave($storage);

    // Ensure exposed_fields is an array.
    if (!is_array($this->exposed_fields)) {
      $this->exposed_fields = [];
    }
  }

}
