<?php

namespace Drupal\graphql_compose_configs;

/**
 * Common methods for GraphQL config naming.
 */
trait GraphQLConfigNamingTrait {

  /**
   * Creates a valid GraphQL type name from a configuration name.
   *
   * @param string $config_name
   *   The configuration name.
   *
   * @return string
   *   A valid GraphQL type name.
   */
  protected function createSchemaTypeNameFromConfigName($config_name) {
    // Convert configuration name to valid GraphQL type name.
    // Ex: system.site to SystemSite.
    $parts = preg_split('/[._]/', $config_name);
    return implode('', array_map('ucfirst', $parts));
  }

  /**
   * Creates a valid GraphQL field name from a configuration path.
   *
   * @param string $path
   *   The configuration path.
   *
   * @return string
   *   A valid GraphQL field name.
   */
  protected function createFieldNameFromPath($path) {
    // Split by both dots and underscores.
    $parts = preg_split('/[._]/', $path);
    // Convert each part to camelCase.
    $result = lcfirst(implode('', array_map('ucfirst', $parts)));
    // Remove any remaining invalid characters.
    return preg_replace('/[^a-zA-Z0-9]/', '', $result);
  }

}
