<?php

namespace Drupal\graphql_compose_configs\Plugin\GraphQL\SchemaExtension;

use Drupal\graphql\GraphQL\ResolverBuilder;
use Drupal\graphql\GraphQL\ResolverRegistryInterface;
use Drupal\graphql_compose\Plugin\GraphQL\SchemaExtension\ResolverOnlySchemaExtensionPluginBase;
use Drupal\graphql_compose_configs\GraphQLConfigNamingTrait;

/**
 * Adds configuration data to the GraphQL schema.
 *
 * @SchemaExtension(
 *   id = "graphql_compose_configs_extension",
 *   name = "GraphQL Compose Configs Extension",
 *   description = @Translation("Adds configuration data to the schema."),
 *   schema = "graphql_compose"
 * )
 */
class ConfigSchemaExtension extends ResolverOnlySchemaExtensionPluginBase {

  use GraphQLConfigNamingTrait;

  /**
   * {@inheritdoc}
   */
  public function registerResolvers(ResolverRegistryInterface $registry): void {
    $builder = new ResolverBuilder();

    // Load all configuration exposures.
    $storage = $this->entityTypeManager->getStorage('graphql_config_exposure');
    $exposures = $storage->loadMultiple();

    foreach ($exposures as $exposure) {
      /** @var \Drupal\graphql_compose_configs\Entity\ConfigurationExposure $exposure */
      $config_name = $exposure->getConfigName();
      $exposed_fields = $exposure->getExposedFields();

      // Create field name for the root query.
      $field_name = $this->createFieldNameFromPath($config_name);
      $type_name = $this->createSchemaTypeNameFromConfigName($config_name);

      // Add root query field with language argument.
      // Using a callback to get the argument properly resolved.
      $registry->addFieldResolver(
        'Query',
        $field_name,
        $builder->callback(function ($parent, $args) use ($config_name) {
          // Even though we don't use $parent, we must keep it for the resolver
          // chain to work.
          return [
            'config_name' => $config_name,
            'langcode' => $args['langcode'] ?? NULL,
          ];
        })
      );

      // Add type fields.
      foreach ($exposed_fields as $field) {
        $graphql_field_name = $this->createFieldNameFromPath($field);

        $registry->addFieldResolver(
          $type_name,
          $graphql_field_name,
          $builder->produce('config_data')
            ->map('config_name', $builder->fromValue($config_name))
            ->map('field_path', $builder->fromValue($field))
            ->map('langcode', $builder->callback(function ($parent) {
              return $parent['langcode'] ?? NULL;
            }))
        );
      }
    }
  }

}
